@@ -1,6 +1,6 @@
 use thiserror::Error;
 
-#[derive(Debug, Error)]
+#[derive(Debug, Error, PartialEq)]
 pub enum Error {
     #[error("codec not found")]
     CodecNotFound,
@@ -20,4 +20,14 @@ pub enum Error {
     SdpInvalidSyntax(String),
     #[error("SdpInvalidValue: {0}")]
     SdpInvalidValue(String),
+
+    #[allow(non_camel_case_types)]
+    #[error("{0}")]
+    new(String),
+}
+
+impl Error {
+    pub fn equal(&self, err: &anyhow::Error) -> bool {
+        err.downcast_ref::<Self>().map_or(false, |e| e == self)
+    }
 }
