@@ -11,7 +11,7 @@ pub const EXT_MAP_VALUE_TRANSPORT_CC_URI: &str =
 
 /// MediaDescription represents a media type.
 /// https://tools.ietf.org/html/rfc4566#section-5.14
-#[derive(Debug, Default)]
+#[derive(Debug, Default, Clone)]
 pub struct MediaDescription {
     /// m=<media> <port>/<number of ports> <proto> <fmt> ...
     /// https://tools.ietf.org/html/rfc4566#section-5.14
@@ -54,7 +54,7 @@ impl MediaDescription {
 
     /// New JSEPMediaDescription creates a new MediaName with
     /// some settings that are required by the JSEP spec.
-    pub fn new(codec_type: String, _codec_prefs: Vec<&str>) -> Self {
+    pub fn new_jsep_media_description(codec_type: String, _codec_prefs: Vec<&str>) -> Self {
         MediaDescription {
             media_name: MediaName {
                 media: codec_type,
@@ -98,6 +98,11 @@ impl MediaDescription {
         self
     }
 
+    /// with_fingerprint adds a fingerprint to the media description
+    pub fn with_fingerprint(self, algorithm: String, value: String) -> Self {
+        self.with_value_attribute("fingerprint".to_owned(), algorithm + " " + &value)
+    }
+
     /// WithICECredentials adds ICE credentials to the media description
     pub fn with_ice_credentials(self, username: String, password: String) -> Self {
         self.with_value_attribute("ice-ufrag".to_string(), username)
@@ -174,7 +179,7 @@ impl MediaDescription {
 /// it may be necessary to specify multiple transport ports, the protocol allows
 /// to write it as: <port>/<number of ports> where number of ports is a an
 /// offsetting range.
-#[derive(Debug, Default)]
+#[derive(Debug, Default, Clone)]
 pub struct RangedPort {
     pub value: isize,
     pub range: Option<isize>,
@@ -191,7 +196,7 @@ impl fmt::Display for RangedPort {
 }
 
 /// MediaName describes the "m=" field storage structure.
-#[derive(Debug, Default)]
+#[derive(Debug, Default, Clone)]
 pub struct MediaName {
     pub media: String,
     pub port: RangedPort,
