@@ -44,7 +44,7 @@ pub type Version = isize;
 
 /// Origin defines the structure for the "o=" field which provides the
 /// originator of the session plus a session identifier and version number.
-#[derive(Debug, Default)]
+#[derive(Debug, Default, Clone)]
 pub struct Origin {
     pub username: String,
     pub session_id: u64,
@@ -98,7 +98,7 @@ pub type PhoneNumber = String;
 
 /// TimeZone defines the structured object for "z=" line which describes
 /// repeated sessions scheduling.
-#[derive(Debug, Default)]
+#[derive(Debug, Default, Clone)]
 pub struct TimeZone {
     pub adjustment_time: u64,
     pub offset: i64,
@@ -113,7 +113,7 @@ impl fmt::Display for TimeZone {
 /// TimeDescription describes "t=", "r=" fields of the session description
 /// which are used to specify the start and stop times for a session as well as
 /// repeat intervals and durations for the scheduled session.
-#[derive(Debug, Default)]
+#[derive(Debug, Default, Clone)]
 pub struct TimeDescription {
     /// t=<start-time> <stop-time>
     /// https://tools.ietf.org/html/rfc4566#section-5.9
@@ -126,7 +126,7 @@ pub struct TimeDescription {
 
 /// Timing defines the "t=" field's structured representation for the start and
 /// stop times.
-#[derive(Debug, Default)]
+#[derive(Debug, Default, Clone)]
 pub struct Timing {
     pub start_time: u64,
     pub stop_time: u64,
@@ -140,7 +140,7 @@ impl fmt::Display for Timing {
 
 /// RepeatTime describes the "r=" fields of the session description which
 /// represents the intervals and durations for repeated scheduled sessions.
-#[derive(Debug, Default)]
+#[derive(Debug, Default, Clone)]
 pub struct RepeatTime {
     pub interval: i64,
     pub duration: i64,
@@ -159,7 +159,7 @@ impl fmt::Display for RepeatTime {
 
 /// SessionDescription is a a well-defined format for conveying sufficient
 /// information to discover and participate in a multimedia session.
-#[derive(Debug, Default)]
+#[derive(Debug, Default, Clone)]
 pub struct SessionDescription {
     /// v=0
     /// https://tools.ietf.org/html/rfc4566#section-5.1
@@ -340,6 +340,16 @@ impl SessionDescription {
         Err(Error::CodecNotFound.into())
     }
 
+    /// Attribute returns the value of an attribute and if it exists
+    pub fn attribute(&self, key: &str) -> Option<&String> {
+        for a in &self.attributes {
+            if a.key == key {
+                return a.value.as_ref();
+            }
+        }
+        None
+    }
+
     /// Marshal takes a SDP struct to text
     /// https://tools.ietf.org/html/rfc4566#section-5
     /// Session description
